@@ -388,8 +388,7 @@ $(function(){
 	var ArAr2 = (geochronometer=='Ar-Ar') & (IsoplotR.settings['Ar-Ar'].format==2);
 	var ArAr3 = (geochronometer=='Ar-Ar') & (IsoplotR.settings['Ar-Ar'].format==3);
 	var ThU34 = (geochronometer=='Th-U') & (IsoplotR.settings['Th-U'].format>2);
-	var detrital1 = (geochronometer=='detritals') &
-	    (IsoplotR.settings['detritals'].format==1);
+	var detrital = (geochronometer=='detritals');
 	var omitters = ["U-Pb","Pb-Pb","Th-Pb","Ar-Ar","K-Ca","Rb-Sr","Sm-Nd",
 			"Re-Os","Lu-Hf","U-Th-He","fissiontracks","Th-U","other"];
 	var omissable = ($.inArray(geochronometer,omitters)>-1);
@@ -406,7 +405,7 @@ $(function(){
 		    row.push(Number(val));
 		    good = true;
 		} else {
-		    if (detrital1 & i==0){ // col names
+		    if (detrital & i==0){ // col names
 			row.push(val);
 			good = true;
 		    } else if ((ArAr2 & j==4)|(ThU34 & j==4)) { // rho
@@ -1441,6 +1440,7 @@ $(function(){
 	    $('#mint').val(set.mint);
 	    $('#z0').val(set.z0);
 	    $('#maxt').val(set.maxt);
+	    $('#xlim').val(set.xlim);
             setOption('#bg_option', set.bg.option);
             $('#bg_ramp_start').val(set.bg.ramp_start);
             $('#bg_ramp_end').val(set.bg.ramp_end);
@@ -1555,6 +1555,8 @@ $(function(){
 	    $('#ellipsestroke').val(set.ellipsestroke);
 	    setOption('#evolution-isochron-models',set.model);
 	    $('#clabel').val(set.clabel);
+	    $('#tticks').val(set.tticks);
+	    $('#aticks').val(set.aticks);
 	    break;
 	default:
 	}
@@ -1854,6 +1856,7 @@ $(function(){
 	    pdsettings.mint = check($('#mint').val(),'auto');
 	    pdsettings.z0 = check($('#z0').val(),'auto');
 	    pdsettings.maxt = check($('#maxt').val(),'auto');
+	    pdsettings.xlim = check($('#xlim').val(),'auto');
 	    pdsettings.pch = $('#pch').val();
             pdsettings.bg = {
                 option: getOption('#bg_option'),
@@ -1989,6 +1992,8 @@ $(function(){
 	    pdsettings.ellipsestroke = $('#ellipsestroke').val();
 	    pdsettings.model = getOption("#evolution-isochron-models");
 	    pdsettings.clabel = $('#clabel').val();
+	    pdsettings.tticks = $('#tticks').val();
+	    pdsettings.aticks = $('#aticks').val();
 	    break;
 	default:
 	}
@@ -2892,7 +2897,9 @@ $(function(){
             info: showInfoMessage,
             progress: showProgress
         }).then(function(result) {
-            const rs = result.data.map(function(cs) { return cs.join(','); });
+	    const header = [result.headers.join(',')];
+	    const values = result.data.map(function(cs) { return cs.join(','); });
+	    const rs = header.concat(values);
             const downloader = document.createElement("A");
             downloader.setAttribute("download", fname);
             downloader.setAttribute("href", 'data:text/csv;base64,' + btoa(rs.join('\n')));
